@@ -97,10 +97,10 @@ class RabbitMQService:
                 password=cls._config.get('password', ""),
                 virtualhost=cls._config.get('virtual-host', "/"),
                 connection_pool_size=cls._config.get(
-                    'connection_pool_size', 2),  # 连接池大小
+                    'connection_pool_size', 5),  # 连接池大小
                 channel_pool_size=cls._config.get(
                     'channel_pool_size', 10),       # 通道池大小
-                heartbeat=cls._config.get('heartbeat', 10),
+                heartbeat=cls._config.get('heartbeat', 30),
                 app_name=cls._config.get("APP_NAME", "")
             )
 
@@ -116,9 +116,6 @@ class RabbitMQService:
 
     @classmethod
     async def _create_client(cls, queue_name: str, **kwargs) -> RabbitMQClient:
-        """
-        创建RabbitMQ客户端实例（基于连接池）
-        """
         if not cls._connection_pool:
             # 等待连接池初始化
             start_time = asyncio.get_event_loop().time()
@@ -150,8 +147,9 @@ class RabbitMQService:
             f"允许创建: {create_if_not_exists}"
         )
 
-        return RabbitMQClient(
-            connection_pool=cls._connection_pool,  # 传入连接池实例
+        # 创建客户端实例
+        client = RabbitMQClient(
+            connection_pool=cls._connection_pool,
             exchange_name=cls._config.get(
                 'exchange_name', "system.topic.exchange"),
             exchange_type=kwargs.get('exchange_type', "topic"),
@@ -172,6 +170,10 @@ class RabbitMQService:
                 'consumption_stall_threshold', 10)
         )
 
+        # 使用declare_queue控制是否声明队列（发送器不声明，监听器声明）
+        await client.connect(declare_queue=not is_sender)
+        return client
+
     @classmethod
     async def get_client(
         cls,
@@ -572,11 +574,31 @@ class RabbitMQService:
         # 确保连接有效
         if not sender.is_connected:
             logger.info(f"发送器 '{queue_name}' 连接已关闭，尝试重新连接")
-            try:
-                await sender.connect(force_reconnect=True)
-            except Exception as e:
-                logger.error(f"发送器 '{queue_name}' 重新连接失败: {str(e)}")
-                raise
+            max_retry = 3  # 最大重试次数
+            retry_count = 0
+            last_exception = None
+
+            while retry_count < max_retry:
+                try:
+                    # 尝试重连，每次重试间隔1秒
+                    await sender.connect(force_reconnect=True, declare_queue=False)
+                    logger.info(
+                        f"发送器 '{queue_name}' 第 {retry_count + 1} 次重连成功")
+                    break  # 重连成功则退出循环
+                except Exception as e:
+                    last_exception = e
+                    retry_count += 1
+                    logger.warning(
+                        f"发送器 '{queue_name}' 第 {retry_count} 次重连失败: {str(e)}"
+                    )
+                    if retry_count < max_retry:
+                        await asyncio.sleep(1)  # 重试前等待1秒
+
+            # 所有重试都失败则抛出异常
+            if retry_count >= max_retry and not sender.is_connected:
+                error_msg = f"发送器 '{queue_name}' 经过 {max_retry} 次重连仍失败"
+                logger.error(f"{error_msg}: {str(last_exception)}")
+                raise Exception(error_msg) from last_exception
 
         try:
             # 处理消息数据
