@@ -47,7 +47,7 @@ class NacosService(metaclass=SingletonMeta):
             self.retry_backoff = self.nacos_config.get('retryBackoff', 1.5)
             self.max_retry_delay = self.nacos_config.get('maxRetryDelay', 30)
             self.heartbeat_interval = self.nacos_config.get(
-                'heartbeatInterval', 5)
+                'heartbeatInterval', 10)
             self.register_retry_interval = self.nacos_config.get(
                 'registerRetryInterval', 5)  # 注册重试间隔
 
@@ -87,7 +87,9 @@ class NacosService(metaclass=SingletonMeta):
             # 心跳相关
             self._last_heartbeat_time = 0
             self._heartbeat_fail_count = 0
+            self._heartbeat_lock = threading.Lock()  # 控制心跳线程创建的锁
             self._heartbeat_thread = None
+
             self.max_heartbeat_timeout = self.nacos_config.get(
                 'maxHeartbeatTimeout', 30)  # 最大无心跳时间(秒)
             self._last_successful_heartbeat = time.time()  # 上次成功心跳时间戳
@@ -367,9 +369,9 @@ class NacosService(metaclass=SingletonMeta):
 
             metadata = {
                 "ignore-metrics": "true",
-                "preserved.heart.beat.interval": "3000",  # 心跳间隔 3 秒
-                "preserved.heart.beat.timeout": "15000",  # 心跳超时 15 秒
-                "preserved.ip.delete.timeout": "30000"    # 实例删除超时 30 秒
+                # "preserved.heart.beat.interval": "3000",  # 心跳间隔 3 秒
+                # "preserved.heart.beat.timeout": "15000",  # 心跳超时 15 秒
+                # "preserved.ip.delete.timeout": "30000"    # 实例删除超时 30 秒
             }
             if self.version:
                 metadata["version"] = self.version
@@ -460,64 +462,81 @@ class NacosService(metaclass=SingletonMeta):
         return instance
 
     def start_heartbeat(self):
-        """启动心跳线程"""
-        if self._heartbeat_thread and self._heartbeat_thread.is_alive():
-            return
+        """启动心跳线程（确保单例）"""
+        with self._heartbeat_lock:  # 加锁确保线程安全
+            # 双重检查：先判断线程是否已存在且存活
+            if self._heartbeat_thread is not None and self._heartbeat_thread.is_alive():
+                return
 
-        self._heartbeat_thread = threading.Thread(
-            target=self._send_heartbeat_loop,
-            name="NacosHeartbeatThread",
-            daemon=True
-        )
-        # 设置线程为守护线程并尝试提高优先级
-        self._heartbeat_thread.daemon = True
-        self._heartbeat_thread.start()
+            # 彻底清理可能的残留线程引用
+            self._heartbeat_thread = None
 
-        try:
-            # 尝试提高线程优先级
-            if hasattr(os, 'sched_setscheduler'):
-                os.sched_setscheduler(
-                    self._heartbeat_thread.ident, os.SCHED_FIFO, os.sched_param(99))
-            elif hasattr(os, 'nice'):
-                os.nice(-10)  # 在Unix系统上尝试提高优先级
-            SYLogger.info("nacos:心跳线程已启动并尝试提高优先级")
-        except Exception as e:
-            SYLogger.warning(f"nacos:无法提高心跳线程优先级: {e}")
+            # 创建新的心跳线程
+            self._heartbeat_thread = threading.Thread(
+                target=self._send_heartbeat_loop,
+                name="NacosHeartbeatThread",
+                daemon=True
+            )
+            self._heartbeat_thread.daemon = True
+            self._heartbeat_thread.start()
+            SYLogger.info(f"nacos:心跳线程启动，线程ID: {self._heartbeat_thread.ident}")
 
     def _send_heartbeat_loop(self):
         """优化后的心跳发送循环，确保严格按间隔执行"""
-        SYLogger.info("nacos:优化版心跳线程开始运行")
-        last_heartbeat_time = time.time()  # 初始时间戳
+        current_thread = threading.current_thread()
+        thread_ident = current_thread.ident
+        SYLogger.info(
+            f"nacos:心跳循环启动 - 线程ID: {thread_ident}, "
+            f"配置间隔: {self.heartbeat_interval}秒"
+        )
+
+        consecutive_fail = 0  # 连续失败计数器
 
         while not self._shutdown_event.is_set():
+            # 记录当前时间，作为本次心跳的基准
             current_time = time.time()
-            # 计算距离下次心跳的时间（确保严格按间隔执行）
-            sleep_time = max(0, self.heartbeat_interval -
-                             (current_time - last_heartbeat_time))
 
-            if sleep_time > 0:
-                self._shutdown_event.wait(sleep_time)  # 精准等待
-
-            # 执行心跳逻辑
             try:
-                # 带锁检查注册状态
+                # 检查注册状态（带锁读取）
                 with self._state_lock:
                     registered_status = self.registered
 
-                if registered_status and self.check_service_registered():
+                if not registered_status:
+                    SYLogger.warning(
+                        f"nacos:服务未注册，跳过心跳 - 线程ID: {thread_ident}")
+                    consecutive_fail = 0
+                else:
+                    # 发送心跳
                     success = self.send_heartbeat()
                     if success:
-                        self._last_successful_heartbeat = time.time()
+                        consecutive_fail = 0
+                        self._last_successful_heartbeat = current_time
                         SYLogger.info(
-                            f"nacos:心跳发送成功，时间: {self._last_successful_heartbeat:.3f}")
+                            f"nacos:心跳发送成功 - 时间: {current_time:.3f}, "
+                            f"间隔: {self.heartbeat_interval}秒"
+                        )
                     else:
+                        consecutive_fail += 1
                         SYLogger.warning(
-                            f"nacos:心跳发送失败，已持续{current_time - self._last_successful_heartbeat:.1f}秒")
-                else:
-                    SYLogger.warning("nacos:服务未注册，尝试重新注册")
-                    self._executor.submit(self.register_with_retry)
-            finally:
-                last_heartbeat_time = time.time()  # 更新上次执行时间
+                            f"nacos:心跳发送失败 - 连续失败: {consecutive_fail}次"
+                        )
+                        if consecutive_fail >= 5:
+                            SYLogger.error("nacos:心跳连续失败5次，尝试重连")
+                            self.reconnect_nacos_client()
+                            consecutive_fail = 0
+
+            except Exception as e:
+                consecutive_fail += 1
+                SYLogger.error(
+                    f"nacos:心跳异常: {str(e)}, 连续失败: {consecutive_fail}次")
+
+            # 计算下次执行时间（当前时间 + 配置间隔），确保间隔稳定
+            next_run_time = current_time + self.heartbeat_interval
+            sleep_time = max(0, next_run_time - time.time()
+                             )  # 避免负数（处理耗时超过间隔的情况）
+            self._shutdown_event.wait(sleep_time)  # 精准休眠至下次执行时间
+
+        SYLogger.info(f"nacos:心跳循环已停止 - 线程ID: {thread_ident}")
 
     def send_heartbeat(self):
         """发送心跳并添加超时控制"""
@@ -650,11 +669,11 @@ class NacosService(metaclass=SingletonMeta):
         finally:
             self._shutdown_event.set()
             # 优雅地关闭线程池
-            if self._executor:
+            if self._executor and not self._executor._shutdown:
                 self._executor.shutdown(wait=True)
-            if self._heartbeat_executor:
+            if self._heartbeat_executor and not self._heartbeat_executor._shutdown:
                 self._heartbeat_executor.shutdown(wait=True)
-            if self._monitor_executor:
+            if self._monitor_executor and not self._monitor_executor._shutdown:
                 self._monitor_executor.shutdown(wait=True)
 
     def handle_signal(self, signum, frame):
